@@ -7,14 +7,16 @@ import deepcrawl
 from deepcrawl.utils import ImmutableAttributesMixin
 from deepcrawl.utils import safe_string_to_datetime
 
-crawl_mutable_fields = (
+crawl_extra_fields = (
     'id',
     'account_id',
     'project_id',
     'reports',
     'reports_changes',
     'downloads',
+)
 
+crawl_mutable_fields = crawl_extra_fields + (
     'crawling_at',
     'finished_at',
     'progress_crawled',
@@ -127,6 +129,22 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
     def __str__(self):
         return f"[{self.account_id} {self.project_id} {self.id}] {self.crawling_at}"
 
+    @property
+    def to_dict_mutable_fields(self):
+        """
+        :return: dictionary with the mutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in crawl_mutable_fields}
+
+    @property
+    def to_dict_immutable_fields(self):
+        """
+        :return: dictionary with the immutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in crawl_immutable_fields}
+
     def load_reports(self, connection=None, filters=None, **kwargs):
         """Loads reports into current instance
 
@@ -210,41 +228,37 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
         """Refresh crawl instance
 
         >>> self.refresh()
-        NotImplementedError
+        [0 1 3] 2020-04-23 11:10:11+00:00
 
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
-        :return: NotImplementedError
-        :rtype: Error
+        :return: Refreshed crawl
+        :rtype: DeepCrawlCrawl
         """
-        # TODO Decide which attributes can be changed/updated
-        raise NotImplementedError
-        # connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
-        # crawl = connection.get_project(self.account_id, self.id)
-        # for key in self.__dict__.keys():
-        #     setattr(self, key, getattr(crawl, key))
-        # return self
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        crawl = connection.get_crawl(self.account_id, self.project_id, self.id)
+        for key in crawl_mutable_fields:
+            setattr(self, key, getattr(crawl, key))
+        return self
 
     def update(self, crawl_data, connection=None):
         """Update crawl instance
 
         >>> self.update(crawl_data)
-        NotImplementedError
+        [0 1 3] 2020-04-23 11:10:11+00:00
 
         :param crawl_data: crawl configuration
         :type crawl_data: dict
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
-        :return: NotImplementedError
-        :rtype: Error
+        :return: Updated crawl
+        :rtype: DeepCrawlCrawl
         """
-        # TODO Decide which attributes can be changed/updated
-        raise NotImplementedError
-        # connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
-        # crawl = connection.update_crawl(self.account_id, self.project_id, self.id, crawl_data)
-        # for key in self.__dict__.keys():
-        #     setattr(self, key, getattr(crawl, key))
-        # return self
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        crawl = connection.update_crawl(self.account_id, self.project_id, self.id, crawl_data)
+        for key in crawl_mutable_fields:
+            setattr(self, key, getattr(crawl, key))
+        return self
 
     def delete(self, connection=None):
         """Delete current crawl instance
