@@ -109,7 +109,7 @@ class DownloadConnection(ApiConnection):
         """Get report download
 
         >>> connection.get_report_download(0, 1, 2, "duplicate_body_content:basic", 6)
-        <deepcrawl.reports.report_row.DeepCrawlReportRow at 0x108a20600>
+        <deepcrawl.downloads.download.DeepCrawlReportDownload at 0x108a20600>
 
         :param account_id: account id
         :type account_id: int
@@ -136,9 +136,9 @@ class DownloadConnection(ApiConnection):
         )
 
     def delete_report_download(self, account_id, project_id, crawl_id, report_id, report_download_id):
-        """Delete report doanload
+        """Delete report download
 
-        >>> response = connection.delete_report_download()
+        >>> response = connection.delete_report_download(0, 1, 2, "duplicate_body_content:basic", 6)
         >>> response.status_code
         204
 
@@ -165,8 +165,8 @@ class DownloadConnection(ApiConnection):
         """Get report downloads
 
         >>> connection.get_report_downloads(0, 1, 2)
-        [<deepcrawl.reports.report_row.DeepCrawlReportRow at 0x104a20570>,
-        <deepcrawl.reports.report_row.DeepCrawlReportRow at 0x128a28600>]
+        [<deepcrawl.downloads.download.DeepCrawlReportDownload at 0x108a20600>,
+        <deepcrawl.downloads.download.DeepCrawlReportDownload at 0x208n20701>]
 
         :param account_id: account id
         :type account_id: int
