@@ -115,7 +115,8 @@ report_download_mutable_fields = report_download_extra_fields + (
     "output_type",
     "date_requested",
     "total_rows",
-    "output_requested"
+    "output_requested",
+    "report_file"
 )
 
 report_download_immutable_fields = (
@@ -149,6 +150,7 @@ class DeepCrawlReportDownload(ImmutableAttributesMixin):
         self.output_type = download_data.get('output_type')
         self.date_requested = safe_string_to_datetime(download_data.get('date_requested'))
         self.total_rows = download_data.get('total_rows')
+        self.report_file = download_data.get('report_file')
 
         # only in create (I think.)
         self.output_requested = download_data.get('output_requested')
