@@ -14,12 +14,19 @@ extraction_mutable_fields = (
     'clean_html_tags'
 )
 
+extraction_immutable_fields = (
+
+)
+
+
+extraction_fields = extraction_mutable_fields + extraction_immutable_fields
+
 
 class DeepCrawlExtraction(ImmutableAttributesMixin):
     """
     Extractions class
     """
-    __slots__ = extraction_mutable_fields
+    __slots__ = extraction_fields
 
     mutable_attributes = extraction_mutable_fields
 
@@ -32,3 +39,19 @@ class DeepCrawlExtraction(ImmutableAttributesMixin):
         self.clean_html_tags = extraction_data.get('clean_html_tags', False)
 
         super(DeepCrawlExtraction, self).__init__()
+
+    @property
+    def to_dict_mutable_fields(self):
+        """
+        :return: dictionary with the mutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in extraction_mutable_fields}
+
+    @property
+    def to_dict_immutable_fields(self):
+        """
+        :return: dictionary with the immutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in extraction_immutable_fields}
