@@ -6,11 +6,13 @@ Issues
 from deepcrawl.utils import ImmutableAttributesMixin
 from deepcrawl.utils import safe_string_to_datetime
 
-issue_mutable_fields = (
+issue_extra_fields = (
     'id',
     'account_id',
     'project_id',
+)
 
+issue_mutable_fields = issue_extra_fields + (
     'title',
     'assigned_to',
     'deadline_at',
@@ -103,3 +105,19 @@ class DeepCrawlIssue(ImmutableAttributesMixin):
 
     def __str__(self):
         return f"[{self.account_id} {self.project_id} {self.id}] {self.title}"
+
+    @property
+    def to_dict_mutable_fields(self):
+        """
+        :return: dictionary with the mutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in issue_mutable_fields}
+
+    @property
+    def to_dict_immutable_fields(self):
+        """
+        :return: dictionary with the immutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in issue_immutable_fields}
